@@ -29,12 +29,11 @@
 #include <common/sessiond-comm/sessiond-comm.h>
 #include <common/uri.h>
 #include <common/utils.h>
-#include <lttng/snapshot.h>
-#include <lttng/session-descriptor.h>
 #include <common/path.h>
 #include <lttng/lttng.h>
 
 static char *opt_output_path;
+static char *opt_session_name;
 static char *opt_url;
 static char *opt_ctrl_url;
 static char *opt_data_url;
@@ -132,9 +131,8 @@ end:
 }
 
 static
-struct lttng_session_descriptor *create_session_descriptor(const char *session_name)
+struct lttng_session_descriptor *create_session_descriptor(void)
 {
-	int ret;
 	ssize_t uri_count;
 	enum output_type output_type;
 	struct lttng_uri *uris = NULL;
@@ -146,6 +144,7 @@ struct lttng_session_descriptor *create_session_descriptor(const char *session_n
 		output_type = OUTPUT_NONE;
 	} else if (opt_output_path) {
 		char *expanded_output_path;
+		int ret;
 
 		output_type = OUTPUT_LOCAL;
 		expanded_output_path = utils_expand_path(opt_output_path);
@@ -162,6 +161,8 @@ struct lttng_session_descriptor *create_session_descriptor(const char *session_n
 			goto end;
 		}
 	} else if (opt_url || opt_ctrl_url) {
+		int ret;
+
 		uri_str1 = opt_ctrl_url ? opt_ctrl_url : opt_url;
 		uri_str2 = opt_data_url;
 
@@ -202,17 +203,17 @@ struct lttng_session_descriptor *create_session_descriptor(const char *session_n
 		case OUTPUT_UNSPECIFIED:
 		case OUTPUT_LOCAL:
 			descriptor = lttng_session_descriptor_snapshot_local_create(
-					session_name,
+					opt_session_name,
 					output_type == OUTPUT_LOCAL ?
 						local_output_path : NULL);
 			break;
 		case OUTPUT_NONE:
 			descriptor = lttng_session_descriptor_snapshot_create(
-					session_name);
+					opt_session_name);
 			break;
 		case OUTPUT_NETWORK:
 			descriptor = lttng_session_descriptor_snapshot_network_create(
-					session_name, uri_str1, uri_str2);
+					opt_session_name, uri_str1, uri_str2);
 			break;
 		default:
 			abort();
@@ -225,7 +226,7 @@ struct lttng_session_descriptor *create_session_descriptor(const char *session_n
 			goto end;
 		}
 		descriptor = lttng_session_descriptor_live_network_create(
-				session_name, uri_str1, uri_str2,
+				opt_session_name, uri_str1, uri_str2,
 				opt_live_timer);
 	} else {
 		/* Regular session. */
@@ -233,17 +234,17 @@ struct lttng_session_descriptor *create_session_descriptor(const char *session_n
 		case OUTPUT_UNSPECIFIED:
 		case OUTPUT_LOCAL:
 			descriptor = lttng_session_descriptor_local_create(
-					session_name,
+					opt_session_name,
 					output_type == OUTPUT_LOCAL ?
 						local_output_path : NULL);
 			break;
 		case OUTPUT_NONE:
 			descriptor = lttng_session_descriptor_create(
-					session_name);
+					opt_session_name);
 			break;
 		case OUTPUT_NETWORK:
 			descriptor = lttng_session_descriptor_network_create(
-					session_name, uri_str1, uri_str2);
+					opt_session_name, uri_str1, uri_str2);
 			break;
 		default:
 			abort();
@@ -280,7 +281,7 @@ end:
  *
  *  Returns one of the CMD_* result constants.
  */
-static int create_session(const char *session_name)
+static int create_session(void)
 {
 	int ret, i;
 	char shm_path[LTTNG_PATH_MAX] = {};
@@ -292,8 +293,8 @@ static int create_session(const char *session_name)
 	const char *created_session_name;
 
 	/* Validate options. */
-	if (session_name) {
-		if (strlen(session_name) > NAME_MAX) {
+	if (opt_session_name) {
+		if (strlen(opt_session_name) > NAME_MAX) {
 			ERR("Session name too long. Length must be lower or equal to %d",
 					NAME_MAX);
 			ret = CMD_ERROR;
@@ -304,11 +305,11 @@ static int create_session(const char *session_name)
 		 * Both are reserved for the default session name. See bug #449 to
 		 * understand why we need to check both here.
 		 */
-		if ((strncmp(session_name, DEFAULT_SESSION_NAME "-",
+		if ((strncmp(opt_session_name, DEFAULT_SESSION_NAME "-",
 					strlen(DEFAULT_SESSION_NAME) + 1) == 0) ||
-				(strncmp(session_name, DEFAULT_SESSION_NAME,
+				(strncmp(opt_session_name, DEFAULT_SESSION_NAME,
 					strlen(DEFAULT_SESSION_NAME)) == 0 &&
-				strlen(session_name) == strlen(DEFAULT_SESSION_NAME))) {
+				strlen(opt_session_name) == strlen(DEFAULT_SESSION_NAME))) {
 			ERR("%s is a reserved keyword for default session(s)",
 					DEFAULT_SESSION_NAME);
 			ret = CMD_ERROR;
@@ -328,7 +329,7 @@ static int create_session(const char *session_name)
 		goto error;
 	}
 
-	session_descriptor = create_session_descriptor(session_name);
+	session_descriptor = create_session_descriptor();
 	if (!session_descriptor) {
 		ret = CMD_ERROR;
 		goto error;
@@ -374,7 +375,7 @@ static int create_session(const char *session_name)
 		 * An auto-generated session name already includes the creation
 		 * timestamp.
 		 */
-		if (session_name) {
+		if (opt_session_name) {
 			uint64_t creation_time;
 			struct tm *timeinfo;
 			time_t creation_time_t;
@@ -654,7 +655,6 @@ int cmd_create(int argc, const char **argv)
 {
 	int opt, ret = CMD_SUCCESS, command_ret = CMD_SUCCESS, success = 1;
 	char *opt_arg = NULL;
-	const char *arg_session_name = NULL;
 	const char *leftover = NULL;
 	static poptContext pc;
 
@@ -761,9 +761,7 @@ int cmd_create(int argc, const char **argv)
 			goto end;
 		}
 	}
-
-	/* Get the optional session name argument. */
-	arg_session_name = poptGetArg(pc);
+	opt_session_name = (char*) poptGetArg(pc);
 
 	leftover = poptGetArg(pc);
 	if (leftover) {
@@ -772,7 +770,7 @@ int cmd_create(int argc, const char **argv)
 		goto end;
 	}
 
-	command_ret = create_session(arg_session_name);
+	command_ret = create_session();
 	if (command_ret) {
 		success = 0;
 	}
