@@ -9,10 +9,11 @@
 #define _COMPAT_FCNTL_H
 
 #include <fcntl.h>
-#include <errno.h>
 #include <sys/types.h>
 
-#if (defined(__FreeBSD__) || defined(__CYGWIN__))
+#include <common/compat/errno.h>
+
+#if (defined(__CYGWIN__))
 typedef long long off64_t;
 #endif
 
@@ -59,15 +60,6 @@ static inline ssize_t splice(int fd_in, loff_t *off_in, int fd_out, loff_t *off_
 }
 #endif
 
-#ifdef __FreeBSD__
-#define POSIX_FADV_DONTNEED 0
-
-static inline int posix_fadvise(int fd, off_t offset, off_t len, int advice)
-{
-	return -ENOSYS;
-}
-#endif
-
 #if !(defined(__linux__) || defined(__FreeBSD__) || defined(__CYGWIN__) || defined(__sun__) || defined(__APPLE__))
 #error "Please add support for your OS."
 #endif /* __linux__ , __FreeBSD__, __CYGWIN__, __sun__, __APPLE__ */
